#
# spec file for package rrdtool
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rrdtool
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cairo-devel
BuildRequires:  freetype2-devel
BuildRequires:  gettext-tools
BuildRequires:  glib2-devel
BuildRequires:  groff
BuildRequires:  intltool
BuildRequires:  libart_lgpl-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  lua51-devel
BuildRequires:  pango-devel
BuildRequires:  python-devel
BuildRequires:  ruby-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  tcl-devel
BuildRequires:  tcpd-devel
Requires:       perl = %{perl_version}
Version:        1.4.7
Release:        26.3.1
%define cgilib_version 0.7
Source:         http://oss.oetiker.ch/rrdtool/pub/rrdtool-%{version}.tar.gz
Patch1:         rrdtool-lua-ruby_lib64.patch
Patch2:         rrdtool-tclversion.patch
Patch3:         rrdtool-tclsegfault.patch
Source1:        http://www.infodrom.org/projects/cgilib/download/cgilib-%{cgilib_version}.tar.gz
Patch11:        cgilib-fix_automake.patch
#PATCH FIX UPSTREAM BNC#793636
Patch12:        rrdtool-zero_vs_nothing.patch
Patch13:        rrdtool-1.4.7-CVE-2013-2131-imginfo_format_check.patch
Patch14:        rrdtool-1.4.7-pango-fontmap-threading-issue.patch
Source2:        sysconfig.rrdcached
Source4:        rrdcached-systemd-pre
Source5:        rrdcached.service
Url:            http://oss.oetiker.ch/rrdtool/
Summary:        A tool for data logging and analysis
License:        GPL-2.0+
Group:          Productivity/Scientific/Math
Requires:       dejavu
Requires(pre):  pwdutils

%description
A tool to log and analyze data gathered from all kinds of data sources.
The data analysis part of RRDtool is based on the ability to quickly
generate graphical representations of the data values collected over a
definable time period.

%package devel
Summary:        A tool for data logging and analysis - Development files
Group:          Development/Libraries/Other
Requires:       %name = %version

%description devel
A tool to log and analyze data gathered from all kinds of data sources.
The data analysis part of RRDtool is based on the ability to quickly
generate graphical representations of the data values collected over a
definable time period.

%package -n python-rrdtool
Summary:        Python bindings for rrdtool
Group:          Productivity/Scientific/Math
Requires:       %name = %version
%py_requires

%description -n python-rrdtool
A tool to log and analyze data gathered from all kinds of data sources.
The data analysis part of RRDtool is based on the ability to quickly
generate graphical representations of the data values collected over a
definable time period.

This package contains the Python bindings


%package -n lua-rrdtool
Summary:        Lua bindings for rrdtool
Group:          Productivity/Scientific/Math
Requires:       %name = %version

%description -n lua-rrdtool
A tool to log and analyze data gathered from all kinds of data sources.
The data analysis part of RRDtool is based on the ability to quickly
generate graphical representations of the data values collected over a
definable time period.

This package contains the Lua bindings

%package -n ruby-rrdtool
Summary:        Ruby bindings for rrdtool
Group:          Productivity/Scientific/Math
Requires:       ruby

%description -n ruby-rrdtool
A tool to log and analyze data gathered from all kinds of data sources.
The data analysis part of RRDtool is based on the ability to quickly
generate graphical representations of the data values collected over a
definable time period.

This package contains the Ruby bindings

%package -n tcl-rrdtool
Summary:        Tcl bindings for rrdtool
Group:          Productivity/Scientific/Math
Requires:       tcl

%description -n tcl-rrdtool
A tool to log and analyze data gathered from all kinds of data sources.
The data analysis part of RRDtool is based on the ability to quickly
generate graphical representations of the data values collected over a
definable time period.

This package contains the Tcl bindings

%package cached
Summary:        Data caching daemon for RRDtool
Group:          Productivity/Scientific/Math
Requires:       %{name} = %{version}
Requires(pre):  %fillup_prereq
%{?systemd_requires}
%define         rrdcached_user rrdcached
%define         rrdcached_group rrdcached

%description cached
rrdcached is a daemon that receives updates to existing RRD files,
accumulates them and, if enough have been received or a defined time has
passed, writes the updates to the RRD file.  The daemon was written with
big setups in mind which usually runs into I/O related problems.  This
daemon was written to alleviate these problems.

%prep
%setup -q -a1
%if %{_lib}==lib64
%patch1
%endif
%patch2
%patch3
pushd "cgilib-%{cgilib_version}"
%patch11
popd #cgilib
%patch12 -p1
%patch13 -p1
%patch14 -p1

%build
# first prepare cgilib
pushd cgilib-%{cgilib_version}
echo -n > NEWS
aclocal --force
autoreconf -fiv
CGILIB_CFLAGS="%{optflags} -fPIC -I."
CGILIB_CFLAGS="$CGILIB_CFLAGS -fexcess-precision=fast"
CFLAGS="$CGILIB_CFLAGS" \
%configure
make %{?jobs:-j %jobs}
%__mkdir_p ../lb/include
%__cp *.h ../lb/include/
%__mkdir_p ../lb/lib/
%__cp -a .libs/libcgi.so* ../lb/lib/
popd #cgilib

# build rrdtool
if [ ! -d m4 ]; then mkdir m4; fi
# we need getext 0.18
#autoreconf -i -f
export LDFLAGS="-L`pwd`/lb/lib" CPPFLAGS="-I`pwd`/lb/include" \
%configure --disable-static --with-pic --enable-shared \
	    --enable-tcl-site \
            --with-tcllib=%{_libdir} \
            --with-gnu-ld \
	    --enable-python \
	    --enable-ruby \
	    --enable-ruby-site-install \
            --disable-rpath \
            --with-rrd-default-font="monospace" 
make %{?jobs:-j %jobs} V=1

%install
#eval `perl -V:installarchlib`
# Override hdrdir and rubyhdrdir to avoid makefile dependencies on
# installed ruby headers to be prefixed with %{buildroot}
make \
    DESTDIR=$RPM_BUILD_ROOT \
    idocdir=%{_docdir}/%{name}/txt/ \
    ihtmldir=%{_docdir}/%{name}/html/ \
    examplesdir=%{_docdir}/%{name}/examples/ \
    libdir=%{_libdir} \
    pkglibdir=%tcl_archdir/tclrrd%version \
    install
# we install this later again
rm -r $RPM_BUILD_ROOT%{_prefix}/lib/perl
# do not install fonts (use system fonts instead)
rm -rf $RPM_BUILD_ROOT%_datadir/rrdtool/fonts
# install correctly perl modules
pushd bindings/perl-piped 
perl Makefile.PL
make DESTDIR=$RPM_BUILD_ROOT install_vendor
popd
pushd bindings/perl-shared 
perl Makefile.PL
make DESTDIR=$RPM_BUILD_ROOT install_vendor
popd
%perl_process_packlist
#fix build (it would be better to split cgilib)
#sed 's/[[:space:]]*-L\/usr\/src\/packages\/BUILD\/%{name}-%{version}\/lb\/lib[[:space:]]*/ /' $RPM_BUILD_ROOT/%{_libdir}/librrd.la > tmp
#mv tmp $RPM_BUILD_ROOT/%{_libdir}/librrd.la
#sed 's/[[:space:]]*-L\/usr\/src\/packages\/BUILD\/%{name}-%{version}\/lb\/lib[[:space:]]*/ /' $RPM_BUILD_ROOT/%{_libdir}/librrd_th.la > tmp
#mv tmp $RPM_BUILD_ROOT/%{_libdir}/librrd_th.la
find "%{buildroot}" -type f -name '*.la' -exec %__rm {} \;
# install ruby bindings
pushd bindings/ruby
mkdir -p %{buildroot}%{rb_sitearchdir}
make DESTDIR=%{buildroot} install
popd
# documentation
install -m 644 CHANGES CONTRIBUTORS COPYING COPYRIGHT README TODO $RPM_BUILD_ROOT/%{_docdir}/%{name}
pushd doc
mkdir txt
mkdir html
mv *.txt txt/
mv *.html html/
popd
rm examples/rrdcached/Makefile*
chmod -x examples/*
chmod +x examples/rrdcached
# install rrdcached specials
install -Dm644 %{SOURCE2} %{buildroot}%{_localstatedir}/adm/fillup-templates/sysconfig.rrdcached
# install systemd specific files
install -Dm755 %{SOURCE4} %{buildroot}%{_datadir}/rrdcached/rrdcached-systemd-pre
install -Dm644 %{SOURCE5} %{buildroot}%{_unitdir}/rrdcached.service
mkdir -p %{buildroot}%{_localstatedir}/lib/rrdtool/rrdcached

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc %{_docdir}/rrdtool
%doc %{_mandir}/*/*
%{_bindir}/*
%exclude %{_bindir}/rrdcached
%{_libdir}/librrd.so.*
%{_libdir}/librrd_th.so.*
%{perl_vendorlib}/RRDp.pm
%{perl_vendorarch}/RRDs.pm
#%{perl_vendorarch}/ntmake.pl
%{perl_vendorarch}/auto/*
#%{_datadir}/%{name}

%files devel
%defattr(-, root, root)
%{_includedir}/*
%{_libdir}/librrd_th.so
%{_libdir}/librrd.so
%{_libdir}/pkgconfig/librrd.pc

%files -n python-rrdtool
%defattr(-, root, root)
%{py_sitedir}/*

%files -n lua-rrdtool
%defattr(-, root, root)
%dir %{_libdir}/lua
%dir %{_libdir}/lua/*
%{_libdir}/lua/*/rrd.so
%{_libdir}/lua/*/rrd.so.*

%files -n tcl-rrdtool
%defattr(-, root, root)
%{tcl_archdir}/*
%{_libdir}/tclrrd*.so

#%{!?rb_sitearchdir: %define rb_sitearchdir %(ruby -rrbconfig -e 'puts RbConfig::CONFIG["sitearchdir"]')}

%files -n ruby-rrdtool
%defattr(-, root, root)
%{rb_sitearchdir}/RRD.so

%files cached
%defattr(-, root, root)
%{_bindir}/rrdcached
%{_localstatedir}/adm/fillup-templates/sysconfig.rrdcached
%dir %{_localstatedir}/lib/rrdtool
%attr(-,%rrdcached_user,%rrdcached_group) %dir %{_localstatedir}/lib/rrdtool/rrdcached
%{_datadir}/rrdcached
%{_datadir}/rrdcached/rrdcached-systemd-pre
%{_unitdir}/rrdcached.service

%pre cached
getent group %rrdcached_group >/dev/null || groupadd %rrdcached_group
getent passwd %rrdcached_user >/dev/null || useradd -s /sbin/nologin -g %rrdcached_group -c %rrdcached_user -d %{_localstatedir}/lib %rrdcached_user
%service_add_pre rrdcached.service

%post cached
%service_add_post rrdcached.service
%fillup_only rrdcached

%preun cached
%service_del_preun rrdcached.service

%postun cached
%service_del_postun rrdcached.service

%changelog
* Tue Feb 13 2018 kstreitova@suse.com
- add rrdtool-1.4.7-pango-fontmap-threading-issue.patch to fix
  infinite loop and crashing with pango [bsc#1080251]
- add rrdtool-1.4.7-CVE-2013-2131-imginfo_format_check.patch that
  adds check to the imginfo format to prevent crash or exploit
  [bsc#828003], [CVE-2013-2131]
* Wed Oct 14 2015 kstreitova@suse.com
- switch from BuildRequires: systemd to systemd-rpm-macros
* Wed Jun 18 2014 mrueckert@suse.de
- create the site_ruby path before installing files there
* Mon Nov 18 2013 vdziewiecki@suse.com
- Fix bnc#793636 almost undistinguishable wheter there is "no data"
  or "zero valued data" on the rendered graph - rrdtool-zero_vs_nothing.patch
- I did this to prepare rrdtool for SLE12 - bnc#831773 - [openSUSE goes SLE12]: rrdtool: Change and/or patches may have been lost
* Fri Oct  4 2013 p.drouand@gmail.com
- Remove PIDfile definition of sysconfig file and add it in systemd
  service file
- Fix PIDfile location to /run instead of var/lib/rccached
* Fri Oct  4 2013 obs@botter.cc
- fix rrdcached service file (type=forking), add pid file variable
* Thu Oct  3 2013 p.drouand@gmail.com
- Build is disable for SLE; remove sysvinit support
- CLean obsolete conditionnal macros
- Fix devel package Group; it have to be Development/Libraries
* Wed Oct  2 2013 obs@botter.cc
- add systemd service for rrdcached
* Wed Jul 10 2013 dvaleev@suse.com
- rename rrdtool-lua_lib64.patch to rrdtool-lua-ruby_lib64.patch
  since it sets libdir for ruby as well
- Package ruby bindings into ruby-rrdtool package
* Sat Jun  1 2013 schwab@suse.de
- Work around makefile dependencies on installed ruby headers during
  installation
- Avoid running autoreconf, remove rrdtool-automake.patch
* Wed May 29 2013 mhrusecky@suse.com
- Fix the hack from previous entry to work everywhere
* Thu May 16 2013 vdziewiecki@suse.com
- Fix build failure: make looks for ruby.h in wrong place.
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Sat Jan 12 2013 coolo@suse.com
- remove suse_update_config
* Fri Oct 26 2012 coolo@suse.com
- add explicit buildrequire on groff for man pages
* Thu May 24 2012 idonmez@suse.com
- Fix build with new automake
* Tue Apr  3 2012 saschpe@suse.de
- Only require lua51-devel on openSUSE_12.2 or later
* Mon Mar  5 2012 vdziewiecki@suse.com
- update to 1.4.7
  * check in /usr/lib64 for tclConfig.sh too
  * remove perl 5.004 compatibility hack and make RRDs compile with newer
    perls.
  * added support for rrdgraph to use the yotta, zetta, zepto, yocto prefixes.
  * configure option to disable building rrd_graph: --disable-rrd_graph
    With support from Ulf Zimmermann (OpenLane)
  * fixed segfault in rrdtool (xport, fetch, graph) when handling
    error conditions. -- James Brown
  * fix uninitialized variable in rrd_graph (#322)
  * improved data reduction algorithm in graph: after fetching, data must be
    reduced to at least chart resolution, else some data will not get plotted.
    fix for #298
  * plug memory leak in lua bindings #301
  * improve cross compiling -- Michael Olbrich
* Mon Jan 30 2012 dmueller@suse.de
- require lua51-devel
* Thu May 12 2011 max@novell.com
- Fix two segfaults in the Tcl binding.
* Wed May 11 2011 max@novell.com
- Move the Tcl bindings into a separate subpackage.
- Remove the superfluous call to (bnc#693085).
- Adopt the current practice of packaging Tcl extensions.
* Tue Dec 28 2010 pascal.bleser@opensuse.org
- build lua bindings (new subpackage lua-rrdtool)
- update to 1.4.5:
  * rrdcached: print \n at the end of log messages when running rrdcached in the foreground
  * rrdcached: Let the -s, -m and -P options affect the default socket as well
  * rrdgraph: font related memory leaks fixed #208
  * rrdgraph-libdbi: print error message instead of dumping core on sql problem
  * rrdgraph-libdbi: properly allocated response buffer
  * rrdtool: in remote mode, make argument count for remote commmands strict
  * rrdgraph: fix problems with second %%s in right-axis format
  * everywhere: fix locale handling. locales were not properly reset after calling set locale
  * rrdgraph: fix use of %%s in strftime (G)PRINT commands #277
  * ruby: fix bindings to be compatible with curent ruby implementations #279
  * rrdcached: Ensure that response_read() always calls fflush() or fclose() #278
  * rrd_client: free addrinfo list after use ...
  * rrdupdate: follow the normal code path for exiting rrd_update if there is a problem with rrdc, plugging a memory leak on the way
  * rrdgraph: make sure we do not try to draw points all that far outside the drawing area since some versions of cairo seem to go unstable when this happens
  * rrdgraph: fix an endles loop near 2^31 timestamp (32bit platform problem)
  * rrdcached: fix permissions of the default socket
  * rrdgraph-libdbi: Fix sigma calculation
  * rrdcreate: better checks for RRA arguments
  * rrdgraph: if there is no right label, do not reserve any space for it
  * Enhancements:
    + rrdcached: add hosts_access support
    + rrdfetch/graph: introduce "epoch" as a new base time reference, meaning timestamp 0: you can now write epoch+11111111s or epoch+19711205s
  * update in-tree cgilib to 0.7:
    + allow cookies without regular CGI POST/GET variables
    + support for ';' as delimiter
    + support for multipart/form-data
    + support for file upload
    + decode variable names and data
* Tue Dec  7 2010 coolo@novell.com
- fix perl file list on factory
* Tue Jul 27 2010 anicka@suse.cz
- update to 1.4.4
  * legal: Relicense the RRDCacheD client interface under the MIT
  license
  * legal: Updted FLOSS Exception for latest PHP license
  * rrd_cached: better help output
  * bugfixes
- remove last patch, fixed in upstream
- disable calling autoreconf (needs too new gettext)
* Fri Apr 16 2010 anicka@suse.cz
- fixed bnc#594981 (-double.diff)
* Tue Mar 30 2010 anicka@suse.cz
- update to 1.4.3
  * rrdcached: Log to stderr (in addition to syslog) when running
  in foreground.
  * rrdcached: Added -m command line option.
  * rrdcached: Added -s option so set group permissions of the
  UNIX domain socket.
  * rrd_create: added --no-overwrite option. It prevents rrdtool
  from clobbering existing rrd files.
  * ruby bindings: rb_rrd_xport function
  * use locale settings and _NL_TIME_WEEK_1STDAY to determine
  the first day of the week. Works on Linux at least
  * rrd_graph: \u to backup one line for special legend placement
  tricks
  * rrd_update: new (better) checker for incoming COUNTER
  or DERIVED data.
* Mon Mar  8 2010 coolo@novell.com
- update to 1.4.2
  * RRD Caching Daemon (rrdcached)
  See rrdcached documentation.
  * The output of rrdtool dump has been adjusted to be simpler to parse by
  existing xml parsers.
  * RRD Graphing functions (rrdtool graph)
  + VDEF PERCENTNAN (a PRECENT that ignores NAN)
  + CDEF PREDICT and PREDICTSIGMA functions for on-the-fly
    data prediction without the need to modify existing rrd files as it is
    required for HoltWinters.
  + LibDBI integration provides a path to read data directly of a supported
    SQL database into rrdtool graph. See rrdgraph_libdbi documentation.
  * quite some more - see NEWS and CHANGES
* Mon Apr 20 2009 crrodriguez@suse.de
- use --disable-static instead of removing static libraries
* Mon Apr 20 2009 anicka@suse.cz
- update to 1.3.7
  * many small updates to the POD documents.
  * improved win32 source
  * OSX compilation fixes
  * rrd_fetch: fix memory leak
  * rrd_cgi: fix segfault in error reporting routine
  * rrd_graph: fix TICK for negative numbers
  * rrd_graph: fix image size reporting for LP64BE architectures
  * rrd_resize: fix GROW for mmap (it was totally broken)
* Wed Feb  4 2009 mfabian@suse.de
- bnc#467362: use --with-rrd-default-font="monospace" instead of
  - -with-rrd-default-font=/usr/share/fonts/truetype/DejaVuSansMono.ttf,
  rrdtools uses fontconfig now, not only freetype and the latter
  is not a correct font name for fontconfig.
* Fri Jan 23 2009 anicka@suse.cz
- update to 1.3.6
  * bugfixes, documentation improvements
* Mon Oct  6 2008 anicka@suse.cz
- update to 1.3.4
  * detect short/truncated files on open (rrdtool used to crash
  later on some platforms)
  * stop rrd_resize from altering the original file (mmap side
  effect)
  * fix VDEF and SHIFT use. Now it returns correct data and does
  not crash anymore.
  * fix rrd_xport when used on datasources with different
  resolutions. This has been broken from day 1 of this tools
  exsitance.
  * fixed default prefix for ruby install
  * added rpath for perl bindings on bsd
  * do not [fm]advise past the end of the file since this
  causes crashes on sparc.
* Wed Sep 10 2008 anicka@suse.cz
- update to 1.3.2
  * fix for data corruption bug:
  http://oss.oetiker.ch/rrdtool-trac/ticket/178
* Mon Jul 28 2008 coolo@suse.de
- remove la files and static libs (to fix depending packages)
* Mon Jun 30 2008 schwab@suse.de
- Fix configure script and use of libtool.
* Fri Jun 27 2008 anicka@suse.cz
- update to 1.3.0
  * Multiplicative Holt-Winters Forecasting
  * MMAP IO
  * Graphing with Cairo/Pango
  * New graphv Interface
  * many more changes - major release
* Mon Mar 10 2008 anicka@suse.cz
- update to 1.2.27
  * bindings/ruby/main.c: be more helpful when raising rb_eTypeError
  in string_arr string_arr_new(VALUE rb_strings).
  * src/rrd_update.c: dropping cache after update does not help (in
  this implementation)
  * bindings/Makefile.am, bindings/python/setup.py: yet another
  attempt to make the python build environment REALY cool
  * bindings/Makefile.am, bindings/python/setup.py: make sure the
  python extension gets the final resting place of the rrdlibrary
  compiled in ...
  * src/rrd_graph.c: don't use round since it is c99 ... use
  floor(x+0.5) for positive numbers instead.
  * src/rrd_graph.c: added some more rounding for int to float
  comparisons
  * src/rrd_graph.c: Testing an double and an integer for equality is
  bound to produce odd results on times. Don't do it! --
  * bugfixes, documentation fixes
- remove python patch (fixed in upstream)
* Wed Feb 20 2008 dmueller@suse.de
- make dejavu font requirement unversioned again, as
  there was no released openSUSE distro with the wrongly
  named font
* Mon Jan 14 2008 dmueller@suse.de
- dejavu font was renamed back, adjust
* Wed Nov 28 2007 dmueller@suse.de
- fix default font after dejavu font update
- add dejavu to the package requires
- build parallel
* Mon Jul  9 2007 dmueller@suse.de
- apply python requires only to python-rrdtool subpackage
* Thu Jun 21 2007 dmueller@suse.de
- split off python and -devel package to reduce
  size and make the python dependency optional
  (needed for 1 CD installer)
* Thu May 24 2007 ro@suse.de
- added ldconfig to post scripts
* Wed May  9 2007 anicka@suse.cz
- fix rpath in python module
* Fri May  4 2007 anicka@suse.cz
- update to 2.1.23
  * many bugfixes (mostly python)
- remove stderr.diff and buffer.diff (fixed in upstream)
* Mon Jan 29 2007 anicka@suse.cz
- update to 1.2.18
  * many bugfixes
  * DoS in rrd_graph.c fixed [#231212]
- fix overflow in rrd_tool.c
* Fri Jan  5 2007 anicka@suse.cz
- fix librrd_th.la
- remove packaged fonts and use system fonts instead
- fix last patch
* Tue Jan  2 2007 anicka@suse.cz
- fix memory allocation bug when graphing logarithmic data
  with upstream patch [#231212]
* Mon Sep 25 2006 anicka@suse.cz
- use %%py_requires [#207920]
* Fri Sep 15 2006 anicka@suse.cz
- store value returned with PyTuple_Size in
  Py_ssize_t instead of int
* Mon Jul 17 2006 anicka@suse.cz
- update to 1.2.15
  * vnames can be up to MAX_VNAME_LEN long
  * bugfixes, documentation fixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan  5 2006 anicka@suse.cz
- update to 1.2.12
* Wed Dec 14 2005 max@suse.de
- Fixed installation of the Tcl bindings.
* Tue Nov  1 2005 anicka@suse.cz
- fix build - return proper value from strerror_r
* Wed Sep 21 2005 anicka@suse.cz
- fix build
* Sun Jul 31 2005 cthiel@suse.de
- moved pkgIndex.tcl to /usr/share/tcl/tclrrd
* Tue Jul 26 2005 cthiel@suse.de
- update to 1.2.11
* Tue Jun 21 2005 anicka@suse.cz
- update to 1.2.10
- drop no longer neccessary rrdtool-tcl.patch
* Thu May 19 2005 mcihar@suse.cz
- update to 1.2.8
- reneabled tcl (copilation fixed by rrdtool-tcl.patch)
- added python bindings
* Tue May 10 2005 mcihar@suse.cz
- update to 1.2.6
- dropped tcl for now, it's somewhat broken
* Mon Apr 18 2005 mcihar@suse.de
- include correct config.h
* Wed Aug 11 2004 tcrhak@suse.cz
- update to 1.0.49
* Fri Aug  6 2004 tcrhak@suse.cz
- update to 1.0.48
* Thu Mar  4 2004 tcrhak@suse.cz
- do not use its own (and old) libpng and libz
* Wed Feb 18 2004 tcrhak@suse.cz
- update to version 1.0.46
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Wed Aug 20 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 28 2003 tcrhak@suse.cz
- removed %%{vendor_perl}/auto from filelist
* Mon Jul 28 2003 tcrhak@suse.cz
- update to version 1.0.45
- fixed file list
- require perl
* Mon Jul 28 2003 ro@suse.de
- install perl files to vendor location
* Fri May 23 2003 ro@suse.de
- fix build with current libtool
* Sun Jan 12 2003 tcrhak@suse.cz
- update to 1.0.40
* Tue Nov 19 2002 ro@suse.de
- run full autoreconf and extend configure.in for that
* Fri Aug  9 2002 mls@suse.de
- use sitearch macro
* Tue Jul  9 2002 tcrhak@suse.cz
- update to version 1.0.39
* Mon Jun  3 2002 ro@suse.de
- fix build on lib64 platforms
* Mon May  6 2002 tcrhak@suse.cz
- omitted prefix i386-suse-linux from names of binaries
  and example scripts (bug #16105)
* Fri Feb  8 2002 draht@suse.de
- added rrdtool-1.0.33-zlib-zfree.dif against duplicate free() in
  zlib
* Thu Jun 14 2001 adostal@suse.cz
- fix for new autoconf (add libtoolize --force)
* Wed Apr 11 2001 cihlar@suse.cz
- updated to version 1.0.33
* Mon Mar 19 2001 cihlar@suse.cz
- fixed call of suse_update_config
* Fri Jan 26 2001 cihlar@suse.cz
- package created
